import * as d3 from 'd3';

const csvUrl =
  'https://raw.githubusercontent.com/nawindodda/Project_scientific/main/ICRISAT_District_Level_Data.csv';
const width = 800;
const height = 500;
const margin = {
  top: 50,
  right: 50,
  bottom: 70,
  left: 70,
};

const svg = d3
  .select('#root')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const render = (data) => {
  const x = d3
    .scaleBand()
    .domain(data.map((d) => d.Tourist_Place))
    .range([margin.left, width - margin.right])
    .padding(0.2);

  const y = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, (d) =>
        Math.max(d['2019'], d['2020'], d['2021']),
      ),
    ])
    .nice()
    .range([height - margin.bottom, margin.top]);

  svg.selectAll('g').remove();

  const xAxis = (g) =>
    g
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`,
      )
      .call(d3.axisBottom(x).tickSizeOuter(0))
      .call((g) => g.selectAll('.domain').remove())
      .call((g) =>
        g
          .append('text')
          .attr('x', width / 2)
          .attr('y', margin.bottom - 10)
          .attr('fill', 'currentColor')
          .attr('text-anchor', 'middle')
          .text('Tourist Places')
          .attr('class', 'axis-label'),
      );

  const yAxis = (g) =>
    g
      .attr('transform', `translate(${margin.left},0)`)
      .call(d3.axisLeft(y).ticks(null, 's'))
      .call((g) => g.selectAll('.domain').remove())
      .call((g) =>
        g
          .append('text')
          .attr('x', -margin.left)
          .attr('y', height - margin.bottom - 150) // Adjusted y-coordinate to move the label down
          .attr('fill', 'currentColor')
          .attr('text-anchor', 'start')
          .text('Visitors')
          .attr('class', 'axis-label'),
      );

  // Add x-axis line
  svg
    .append('line')
    .attr('x1', margin.left)
    .attr('y1', height - margin.bottom)
    .attr('x2', width - margin.right)
    .attr('y2', height - margin.bottom)
    .attr('stroke', '#ccc');

  // Add y-axis line
  svg
    .append('line')
    .attr('x1', margin.left)
    .attr('y1', margin.top)
    .attr('x2', margin.left)
    .attr('y2', height - margin.bottom)
    .attr('stroke', '#ccc');

  svg
    .append('g')
    .selectAll('rect')
    .data(data)
    .join('rect')
    .attr('class', 'bar')
    .attr('x', (d) => x(d.Year))
    .attr('y', (d) => y(d['RICE PRODUCTION (1000 tons)']))
    .attr('width', x.bandwidth())
    .attr('height', (d) => y(0) - y(d['2021']));

  svg.append('g').call(xAxis);

  svg.append('g').call(yAxis);

  // Title for the graph
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '20px')
    .text('Tourist Places Visitors Graph');

  // Description of the data
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top)
    .attr('text-anchor', 'middle')
    .style('font-size', '14px')
    .style('font-style', 'italic')
    .text(
      'This graph shows the distribution of visitors across different tourist places over the years.',
    );
};

d3.csv(csvUrl, d3.autoType).then((data) => {
  render(data);
});
